@@ -1,9 +1,10 @@
 from qtrangeslider import QRangeSlider
+from qtrangeslider.qtcompat.QtCore import Qt
 from qtrangeslider.qtcompat.QtWidgets import QApplication
 
 app = QApplication([])
 
-slider = QRangeSlider()
+slider = QRangeSlider(Qt.Horizontal)
 
 slider.setValue((20, 80))
 slider.show()
