@@ -72,6 +72,7 @@ class QRangeSlider(QSlider):
         # color
         self._style = RangeSliderStyle()
         self.setStyleSheet("")
+        update_styles_from_stylesheet(self)
 
     # ###############  Public API  #######################
 
@@ -125,7 +126,8 @@ class QRangeSlider(QSlider):
             )
 
         for i, v in enumerate(val):
-            self._setSliderPositionAt(i, v, _update=i == len(val) - 1)
+            self._setSliderPositionAt(i, v, _update=False)
+        self._updateSliderMove()
 
     def barIsRigid(self) -> bool:
         """Whether bar length is constant when dragging the bar.
@@ -173,23 +175,36 @@ class QRangeSlider(QSlider):
             return
         self._position[index] = pos
         if _update:
-            if not self.hasTracking():
-                self.update()
-            if self.isSliderDown():
-                self.sliderMoved.emit(tuple(self._position))
-            if self.hasTracking():
-                self.triggerAction(QSlider.SliderMove)
+            self._updateSliderMove()
+
+    def _updateSliderMove(self):
+        if not self.hasTracking():
+            self.update()
+        if self.isSliderDown():
+            self.sliderMoved.emit(tuple(self._position))
+        if self.hasTracking():
+            self.triggerAction(QSlider.SliderMove)
 
     def _offsetAllPositions(self, offset: int, ref=None) -> None:
         if ref is None:
             ref = self._position
-        _new = [i - offset for i in ref]
         if self._bar_is_rigid:
-            # FIXME: if there is an overflow ... it should still hit the edge.
-            if all(self.minimum() <= i <= self.maximum() for i in _new):
-                self.setSliderPosition(_new)
-        else:
-            self.setSliderPosition(_new)
+            # NOTE: This assumes monotonically increasing slider positions
+            if offset > 0 and ref[-1] + offset > self.maximum():
+                offset = self.maximum() - ref[-1]
+            elif ref[0] + offset < self.minimum():
+                offset = self.minimum() - ref[0]
+        self.setSliderPosition([i + offset for i in ref])
+
+    def _spreadAllPositions(self, shrink=False, gain=1.1, ref=None) -> None:
+        if ref is None:
+            ref = self._position
+        # if self._bar_is_rigid:  # TODO
+
+        if shrink:
+            gain = 1 / gain
+        center = abs(ref[-1] + ref[0]) / 2
+        self.setSliderPosition([((i - center) * gain) + center for i in ref])
 
     def _getStyleOption(self) -> QStyleOptionSlider:
         opt = QStyleOptionSlider()
@@ -199,12 +214,12 @@ class QRangeSlider(QSlider):
         return opt
 
     def _getBarColor(self):
-        return self._style.brush_active or QtGui.QColor()
+        return self._style.brush(self._getStyleOption())
 
     def _setBarColor(self, color):
         self._style.brush_active = color
 
-    barColor = Property(QtGui.QColor, _getBarColor, _setBarColor)
+    barColor = Property(QtGui.QBrush, _getBarColor, _setBarColor)
 
     def _drawBar(self, painter: QStylePainter, opt: QStyleOptionSlider):
 
@@ -309,8 +324,9 @@ class QRangeSlider(QSlider):
             self._setSliderPositionAt(self._pressedControl[1], new)
         elif self._pressedControl[0] == "bar":
             ev.accept()
+
             delta = self._clickOffset - self._pixelPosToRangeValue(self._pick(ev.pos()))
-            self._offsetAllPositions(delta, self._sldPosAtPress)
+            self._offsetAllPositions(-delta, self._sldPosAtPress)
         else:
             ev.ignore()
             return
@@ -335,8 +351,13 @@ class QRangeSlider(QSlider):
         super().setRange(min, max)
         self.setValue(self._value)  # re-bound
 
-    def _handleRects(self, opt: QStyleOptionSlider, handle_index: int = None) -> QRect:
+    def _handleRects(
+        self, opt: QStyleOptionSlider = None, handle_index: int = None
+    ) -> QRect:
         """Return the QRect for all handles."""
+        if opt is None:
+            opt = self._getStyleOption()
+
         style = self.style().proxy()
 
         if handle_index is not None:  # get specific handle rect
@@ -528,7 +549,11 @@ class QRangeSlider(QSlider):
 
         _prev_value = self.value()
 
-        self._offsetAllPositions(-steps_to_scroll)
+        if modifiers & Qt.AltModifier:
+
+            self._spreadAllPositions(shrink=steps_to_scroll < 0)
+        else:
+            self._offsetAllPositions(steps_to_scroll)
         self.triggerAction(QSlider.SliderMove)
 
         if _prev_value == self.value():
